
To do development work for Ninja JWT, make your own fork on Github,
clone it locally, make and activate a virtualenv for it, then from
within the project directory:

``` {.sourceCode .bash}
make install
```

To run the tests:

``` {.sourceCode .bash}
make test
```
To run the tests with coverage:

``` {.sourceCode .bash}
make test-cov
```
